# DeviceRxBuffer

Device message buffer model used for API and database

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**locator** | **str** |  | 
**state** | **str** |  | [optional] 
**timestamp_db_write** | **int** |  | [optional] 
**timestamp_hid_message** | **int** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


